/*! \file ALDCommonCommands.h
 * \brief Объявление классов команд общего назначения Astra Linux Directory
 * \ingroup ALDCommands
*/

#ifndef ALD_COMMON_COMMANDS
#define ALD_COMMON_COMMANDS

#include "ALDCommand.h"

using namespace std;

namespace ALD
{

/*! \defgroup ALDCommonCommands Общие команды Astra Linux Directory
 * \brief Объявление классов команд общего назначения Astra Linux Directory
 * \ingroup ALDCommands
 * @{
 */

/*! \class CALDCmdHelp
 * \brief Класс общей команды 'help'
 */
class CALDCmdHelp: public CALDCommand
{
protected:
    virtual int Execute();

    /// Вывод помощи указанной секции
    virtual void ShowSectionCommands(const string& sectionname);
public:
    virtual void ShowUsage() const;
    virtual void FillRLArguments(const string& option, ald_string_list& list, bool& isfile);

    /// Конструктор
    CALDCmdHelp(IALDCore& Core);
    virtual ~CALDCmdHelp();
};

/*! \class CALDCmdStatus
 * \brief Класс общей команды 'status'
 */
class CALDCmdStatus: public CALDCommand
{
protected:
    virtual int Execute();
public:
    virtual void ShowUsage() const;
    /// Конструктор
    CALDCmdStatus(IALDCore& Core);
    virtual ~CALDCmdStatus();
};

/*! \class CALDCmdCmd
 * \brief Класс общей команды 'cmd'
 */
class CALDCmdCmd: public CALDCommand
{
private:
    bool m_bFromGui;
protected:
    CALDCommands m_Commands;                    ///< Контейнер зарегистрированных команд
    CALDCommandOptions m_CLOptions;             ///< Контейнер опций текущей команды
    CALDCommandOptions m_GlobalCommonCLOptions; ///< Копия контейнера глобальных опций ALD
    string m_strCurrCmdLine;                    ///< Текущая командная строка
    CALDCommandPtr CurrCmd;                     ///< Указатель на текущую команду

    /// Переход к следующей командной строке
    bool NextCmdLine();
    /// Разбор текущей командной строки
    int ParseCommandLine();
    /// Обработка указанного скрипта
    int ProcessScript(const string &strFile);
    /// Обработка командной строки
    int ProcessCmdLine();
    /// Сохранение глобальных опций
    void PreserveCommonCLOptions();
    /// Восстановление глобальных опций
    void RestoreCommonCLOptions();
    virtual void FillRLArguments(const string& option, ald_string_list& list, bool& isfile);
    /// Формирование списка команд для автодополнения ReadLine
    void BuildRLCommands();
    virtual int Execute();
public:
    virtual void ShowUsage() const;
    /// Конструктор
    CALDCmdCmd(IALDCore& Core);
    virtual ~CALDCmdCmd();
};

/*! \class CALDCmdInternalInfo
 * \brief Класс общей команды 'internal-info'
 */
class CALDCmdInternalInfo: public CALDCommand
{
protected:
    virtual int Execute();
public:
    virtual void ShowUsage() const;
    /// Конструктор
    CALDCmdInternalInfo(IALDCore& Core);
    virtual ~CALDCmdInternalInfo();
};

/// Константа суффикса history файла
const string ALD_HISTORY_FILE  = ".history";

///@}
} // ALD

#endif // ALD_COMMON_COMMANDS
