/*! \file ALDOfl.h
 * \brief Определение функций, необходимых для корректного размонтирования ФС
 */

/*
 *  ALD Ofl
 *
 *  Show processes using directories/files/mountpoints
 *
 *  (While it says mountpoint in the source, any directory is acceptable,
 *  as are files.)
 *
 *  written by Jan Engelhardt, 2008
 *  Released in the Public Domain.
 *  (Imported from the hxtools program suite.)
 */

#ifndef ALD_OFL
#define ALD_OFL

#include "common.h"

namespace ALD
{

/*! \brief Поиск и посылка сигналов процессам, использующих указанную точку монтирования
 * @param[in] mnt Точка монтирования
 * @param[in] signum Сигнал
 * @param[out] occupants Карта процессов
 * @return Результат поиска
 */
bool ofl(const string& mnt, unsigned int signum, ald_string_map& occupants);

/*! \brief Поиск и заврешение процессов, использующих указанную точку монтирования
 * @param[in] mnt Точка монтирования
 * @param[in] hup Посылка SIGHUP
 * @param[in] term Посылка SIGTERM
 * @param[in] kill Посылка SIGKILL
 * @param[in] wait Время ожидания ms
 * @param[in] quiet Признак тихого режима
 */
void KillOccupants(const string& mnt, bool hup, bool term, bool kill, unsigned int wait, bool quiet);

} // ALD

#endif //ALD_OFL
