/*! \file ALDStats.h
 * \brief Объявление подсистемы статистики Astra Linux Directory
 * \ref IALDStatProvider_group
 */

#ifndef ALD_STATS
#define ALD_STATS

#include "common.h"
#include <atomic>

namespace ALD
{
/*! \defgroup IALDStatProvider_group Подсистема статистики Astra Linux Directory (IALDStatProvider)
 * \brief Подсистема статистики Astra Linux Directory
 * @{
 */

/// Базовый тип счетчика
typedef uint64_t ald_stat_counter;

/// Возвращет интерфейс провайдера статистики
#define STAT_PROVIDER  IALDStatProvider::GetStatProvider()

/*! \class IALDStatProvider
 * \brief Абстрактный интерфейс провайдера статистики
 */
class IALDStatProvider
{
protected:
    IALDStatProvider(){}
public:
    /// Статическая функция получения провайдера статистики
    static IALDStatProvider* GetStatProvider();

    /// Инициализации именованного провайдера статистики
    virtual void Init(const string &path) = 0;
    /// Завершение работы провайдера статистики
    virtual void Destroy() = 0;

    /// Регистрация именованного счетчика (возвращается индекс счетчика)
    virtual size_t RegisterCounter(const string& name) = 0;
    /// Получение значения счетчика по имени
    virtual ald_stat_counter ReadCounter(const string& name) = 0;

    /// Получение списка имен счетчика
    virtual void EnumerateCounters(ald_string_list& counters) = 0;
    /// Получение карты (имя=>значение) счетчиков
    virtual void GetCounters(ald_string_map& counters) = 0;

    /// Продвижение счетчика по индексу
    virtual void Inc(size_t idx) = 0;
    /// Установка значения счетчика по индексу
    virtual void Set(size_t idx, ald_stat_counter value) = 0;
    /// Получение значения счетчика по индексу
    virtual ald_stat_counter Get(size_t idx) = 0;

    /// Синхронизация
    virtual void Sync() = 0;

    virtual ~IALDStatProvider(){}
};

///@}
} // ALD

#endif //ALD_STATS
