/*! \file ALDThread.h
 * \brief Объявление абстрактного класса потока (thread) CALDAbstractThread
 * \ingroup CALDAbstractThread_group
 */

#ifndef ALD_THREAD
#define ALD_THREAD

#include "common.h"
#include "atomic"
#include "thread"

using namespace std;

namespace ALD
{

/*! \defgroup CALDAbstractThread_group Базовый класс потока обработки (CALDAbstractThread)
 * \brief Базовый класс потока обработки Astra Linux Directory
 * @{
 */

/*! \class CALDAbstractThread
 * \brief Базовый класс потока обработки Astra Linux Directory
 */
class CALDAbstractThread
{
protected:
    bool m_bStarted;                ///< Признак запуска
    bool m_bTerminated;             ///< Признак прерывания
    atomic_bool m_abTerminate;      ///< Внутренний признак прерывания
    thread m_th;                    ///< Дескриптор потока

    /// Перегружаемая процедура обработки
    static void ThreadProc(CALDAbstractThread *owner);

    /// Перегружаемая функция дополнительный действий при запуске
    virtual void Execute() = 0;
    /// Перегружаемая функция дополнительный действий при остановке
    virtual void DoTerminate() {}
public:
    CALDAbstractThread();

    /// Запуск
    bool Start();

    /// Завершение работы (возможно с ожиданием завершения)
    bool Terminate(bool join);

    /// Возвращает состояние
    ///@{
    bool IsTerminated();
    inline bool IsStarted() const {return m_bStarted;}
    inline bool IsCompleted() {return IsTerminated() && m_bStarted;}
    ///@}

    /// Ожидание завершения работы
    void Join();

    virtual ~CALDAbstractThread();
};

///@}

} // ALD

#endif //ALD_THREAD
