/*! \file action-definitions.h
 * \brief Объявление идентификаторов событий Astra Linux Directory общего назначения
 * \ingroup ALDActions_group
 */

#ifndef ALD_ACTION_DEFINITIONS
#define ALD_ACTION_DEFINITIONS

namespace ALD
{

/*! \defgroup ALDActions_group События Astra Linux Directory (action-definitions.h)
 * \brief Объявление классов объектной модели данных Astra Linux Directory
 * @{
 */

/*! \name Идентификаторы событий Astra Linux Directory общего назначения */
///@{
// common action definition
#define ALD_LOAD_SETTINGS       "LoadSettings"
#define ALD_COMMIT_CFG_WARN     "CommitConfigWarning"
#define ALD_COMMIT_CFG_PRE      "CommitConfigPreparing"
#define ALD_STOP_SERVICES       "StopServices"
#define ALD_START_SERVICES      "StartServices"
#define ALD_MOUNT_FS            "MountFS"
#define ALD_UMOUNT_FS           "UnMountFS"
#define ALD_SHOW_SECTION_HELP   "SectionHelp"

// for installation
#define ALD_INSTALL_EXTENSION   "InstallExtension"

// after initialization
#define ALD_INIT                "InitALD"

// for schemas before ldaptest
#define ALD_INIT_LDAP_SCHEMA    "InitLdapSchema"

// Start, Stop
#define ALD_STARTING            "Starting"
#define ALD_STARTING_WARN       "StartingWarning"
#define ALD_STOPPING            "Stopping"
#define ALD_STOPPING_WARN       "StoppingWarning"
#define ALD_STARTED             "Started"
#define ALD_STOPPED             "Stopped"

// File Server
#define ALD_INIT_FS             "InitFileServer"
#define ALD_START_FS            "StartFileServer"
#define ALD_STOP_FS            	"StopFileServer"
#define ALD_INSTALL_RC_FS       "InstallFileServerRC"
#define ALD_REMOVE_RC_FS        "RemoveFileServerRC"

// Slave Server
#define ALD_INIT_SS             "InitSlaveServer"
#define ALD_ONLINE_SS           "OnlineSlaveServer"
#define ALD_DISMISS_SS          "DismissSlaveServer"

// Administration
#define ALD_USER_ADDED            "UserAdded"
#define ALD_USER_CK_DELETING      "CheckUserDeleting"
#define ALD_USER_DO_DELETING      "DoUserDeleting"
#define ALD_USER_DELETED          "OnUserDeleted"
#define ALD_USER_SHOW             "ShowUser"

#define ALD_GROUP_ADDED           "GroupAdded"
#define ALD_GROUP_CK_DELETING     "CheckGroupDeleting"
#define ALD_GROUP_DO_DELETING     "DoGroupDeleting"
#define ALD_GROUP_DELETED         "GroupDeleted"
#define ALD_GROUP_SHOW            "ShowGroup"

#define ALD_POLICY_SHOW           "ShowPolicy"

#define ALD_SERVICE_ADDED          "ServiceAdded"
#define ALD_SERVICE_CK_DELETING    "CheckServiceDeleting"
#define ALD_SERVICE_DO_DELETING    "DoServiceDeleting"
#define ALD_SERVICE_DELETED        "ServiceDeleted"
#define ALD_SERVICE_SHOW           "ShowService"

#define ALD_SGROUP_ADDED          "ServiceGroupAdded"
#define ALD_SGROUP_CK_DELETING    "CheckServiceGroupDeleting"
#define ALD_SGROUP_DO_DELETING    "DoServiceGroupDeleting"
#define ALD_SGROUP_DELETED        "ServiceGroupDeleted"
#define ALD_SGROUP_SHOW           "ShowServiceGroup"

#define ALD_HGROUP_ADDED          "HostGroupAdded"
#define ALD_HGROUP_CK_DELETING    "CheckHostGroupDeleting"
#define ALD_HGROUP_DO_DELETING    "DoHostGroupDeleting"
#define ALD_HGROUP_DELETED        "HostGroupDeleted"
#define ALD_HGROUP_SHOW           "ShowHostGroup"

#define ALD_HOST_ADDED          "HostAdded"
#define ALD_HOST_CK_DELETING    "CheckHostDeleting"
#define ALD_HOST_DO_DELETING    "DoHostDeleting"
#define ALD_HOST_DELETED        "HostDeleted"
#define ALD_HOST_SHOW           "ShowHost"
#define ALD_HOST_STATUS         "ShowStatus"
#define ALD_HOST_INIT_SVCS      "InitHostServices"

#define ALD_TD_ADDED          "TrustedDomainAdded"
#define ALD_TD_CK_DELETING    "CheckTrustedDomainDeleting"
#define ALD_TD_DO_DELETING    "DoTrustedDomainDeleting"
#define ALD_TD_DELETED        "TrustedDomainDeleted"
#define ALD_TD_SHOW           "ShowTrustedDomain"

#define ALD_FILESRV_SHOW        "ShowFileServer"

#define ALD_DELETE_OBJECT      "DeleteObject"

#define ALD_UPDATE_KRB_ACL      "UpdateKrbAcl"
#define ALD_APPLY_KRB_ACL       "ApplyKrbAcl"
#define ALD_UPDATE_SYS_KEYTAB   "UpdateSysKeytab"

// Replication
#define ALD_UPDATE_KPROPD_ACL   "UpdateKpropdAcl"
#define ALD_PROPAGATE_KRB_BASE	"PropagateKrbBase"

// Test integrity
#define ALD_TEST_INTEGRITY      "DoTestIntegrity"
#define ALD_TI_CHECK_USER       "DoTestIntegrityUser"
#define ALD_TI_CHECK_GROUP      "DoTestIntegrityGroup"
#define ALD_LDAP_CONSISTENCY    "DoLDAPConsistecy"

// Backup
#define ALD_BACKUP_FILES     	"DoBackupFiles"
#define ALD_RESTORE_FILES    	"DoRestoreFiles"
#define ALD_SERVER_RESTORED     "ALDServerRestored"
#define ALD_PORTABLE_SAVE       "DoPortableSave"
#define ALD_PORTABLE_LOAD       "DoPortableLoad"
#define ALD_PORTABLE_SAVE_STAGE "DoPortableSaveStage"

// Client action definition
#define ALD_PAM_CHECK_ACCOUNT   "PamCheckUserAccounting"
#define ALD_PAM_SESSION_OPENING "PamSessionOpening"
#define ALD_PAM_OPEN_SESSION	"PamOpenSession"
#define ALD_PAM_SESSION_CLOSING "PamSessionClosing"
#define ALD_PAM_CLOSE_SESSION   "PamCloseSession"
#define ALD_PAM_CHECK_SESSION	"PamCheckSession"
#define ALD_PAM_SET_CREDENTIALS	"PamSetCredentials"

#define ALD_MOUNT_HOME          "MountHome"
#define ALD_UMOUNT_HOME         "UnMountHome"

// ALD daemon action definition
#define ALD_TASK_PROCESSING     "TaskProcessing"
#define ALD_TASK_PENDING        "TaskPending"
#define ALD_EVENT_PENDING       "EventPending"
#define ALD_USERHOME_CREATE     "CreateUserHome"
#define ALD_USERHOME_ARCHIVE    "ArchiveUserHome"
#define ALD_CACHE_PENDING       "CachePending"
#define ALD_BROADCAST_MESSAGE   "BroadcastMessage"
#define ALD_STATISTICS          "Statistics"
#define ALD_LOAD_RPC_COMMANDS	"LoadRpcCommands"
#define ALD_RPCSRV_START        "RpcServerStart"
#define ALD_RPCSRV_STOP         "RpcServerStop"
#define ALD_CONNECTION_LOST     "ConnectionLost"
#define ALD_CONNECTION_RESTORED "ConnectionRestored"

// ALD Task Types
#define ALD_TASK_TYPE_CREATE_HOME       "create-home"
#define ALD_TASK_TYPE_ARCHIVE_HOME      "archive-home"
#define ALD_TASK_TYPE_APPLY_KRB_ACL     "apply-krb-acl"
#define ALD_TASK_TYPE_UPDATE_KRB_ACL    "update-krb-acl"
#define ALD_TASK_TYPE_UPDATE_KPROPD_ACL "update-kpropd-acl"
#define ALD_TASK_TYPE_RM_LDAP_PROVIDER  "remove-ldap-provider"
#define ALD_TASK_TYPE_PROPAGATE_KRB     "propagate-krb-base"
#define ALD_TASK_TYPE_RM_DOCUMENT       "remove-document"

// ALD Event Types
#define ALD_EVENT_TYPE_KICK_USER    "kick-user"
#define ALD_EVENT_TYPE_SVC_RESTART  "service-restart"
#define ALD_EVENT_TYPE_DOC_CHECK    "check-document"
#define ALD_EVENT_TYPE_RECONFIGURE  "reconfigure"

// ALD daemon sockopt action (objects: rpc, udp, unix)
#define ALD_SET_SOCKOPT         "SetSockOpt"
// ALD daemon sockets objects: rpc, udp, unix
#define ALD_SOCK_RPC            "RPC"
#define ALD_SOCK_UDP            "UPD"
#define ALD_SOCK_UNIX           "UNIX"

// ALD daemon fork action (objects: prefork, parent, child)
#define ALD_DAEMON_FORK         "DaemonFork"
#define ALD_RPC_FORK            "RPCFork"
// ALD daemon fork action objects: prefork, parent, child
#define ALD_FORK_PREFORK        "prefork"
#define ALD_FORK_PARENT         "parent"
#define ALD_FORK_CHILD          "child"
///@}

///@}
} // ALD

#endif // ALD_ACTION_DEFINITIONS
