/*! \file common.h
 * \brief Основной заголовочный файл, содержащий необходимый минимум предварительных объявлений и включений других заголовочных файлов
 */

#ifndef ALD_COMMON
#define ALD_COMMON

#include <string>
#include <iostream>
#include <list>

#include "gettext.h"
#include "ALDException.h"
#include "ALDLogProvider.h"
#include "ALDUtils.h"
#include "msg-definitions.h"

namespace ALD
{

class CALDInterface;
class CALDCommandOptions;
class CALDCommands;
class CALDCommand;
class IALDCore;

} // ALD

/*!
 * \mainpage Прикладной программный интерфейс клиента Astra Linux Directory
 *
 * Astra Linux Directory является надстройкой над технологиями LDAP, Kerberos 5, CIFS
 * и обеспечивает автоматическую настройку всех необходимых файлов конфигурации служб,
 * реализующих перечисленные технологии, а так же предоставляет интерфейс управления
 * и администрирования.
 *
 * Служба Astra Linux Directory обладает расширяемой архитектурой, состоящей из ядра, отвечающего за
 * основной функционал системы, ряда интерфейсов (LDAP, Kerberos, Config) и модулей
 * расширения, предназначенных для расширения командного интерфейса утилит и настройки
 * необходимых служб и подсистем, что позволяет расширять функциональность Astra Linux Directory,
 * устанавливая дополнительные пакеты.
 *
 * Состоит из следующих основных частей:
 * - \ref IALDCore_group
 * - \ref CALDApplication_group
 * - \ref CALDLogProvider_group
 * - \ref ALDUtils_group
 * - \ref ALDCoreUtils_group
 * - \ref ALDExceptions_group
 * - \ref ALDCClient_group
 * - \ref IALDStatProvider_group
 * - \ref ALDObjects_group - Для доступа к данным домена используется объектная модель данных. Каждая сущность
 * домена Astra Linux Directory представлена классом, отвечающим за создание, получение,
 * модификацию и удаление экземпляра сущности.
 * - \ref ALDCommands_group - Для реализации командного интерфейса в утилитах управления используются модули расширения,
 * содержащие соответствующие назначению наборы команд.
 *
 * Интерфейсы внешнего взаимодействия:
 * - \ref IALDConfig_group
 * - \ref IALDLdapWrapper_group
 * - \ref IALDKadm5Wrapper_group
 * - \ref IALDRpcWrapper_group
 *
 * Для удобства работы представлены заголовочные файлы со списками необходимых определений:
 * - \ref ALDMessages_group
 * - \ref ALDLDAPDefinitions_group
 * - \ref ALDActions_group
 * - \ref ALDRPCCommands_group
 */


#endif //ALD_COMMON
