/*! \file ldap-definitions.h
 * \brief Объявление констант метаданых LDAP (уникальных имен, классов, атрибутов)
 * \ingroup IALDLdapWrapper_group
 */

#ifndef ALD_LDAP_DEFINITIONS
#define ALD_LDAP_DEFINITIONS

#include <ldap.h>

/*! \defgroup ALDLDAPDefinitions_group Объявление констант метаданых LDAP (ldap-definitions.h)
 * \brief Объявление констант метаданых LDAP (уникальных имен, классов, атрибутов)
 * \details Объявление констант метаданых LDAP (уникальных имен, классов, атрибутов)
 * Определения констант именуются с помощью префикса ALD_LDAP_, за которым следует имя типа записи и окончание имени.\n
 * Окончание может быть именем атрибута или одним из следующих суфиксов:\n
 * Определения с суффиксом _BASE задают пути к записям соответствующего типа в дереве LDAP.\n
 * Определения с суффиксом _OCLASS задают начальный набор классов LDAP для создания записи соответствующего типа.\n
 * Определения с суффиксом _CLASS задают типовые фильтры для выборки записей соответствующего типа.\n
 * \ingroup IALDLdapWrapper_group
 * @{
 */

/// Макрос создания шаблона протоколирования по типу и имени записи LDAP
#define ALD_LDAP_LOG_TPL(type, name)  ALD_LDAP_##type##_NAME "=" name "," ALD_LDAP_##type##_BASE

//  ALD LDAP STRUCT
/*! \name константы метаданых LDAP (пользователи) */
///@{
#define ALD_LDAP_USER_BASE          "ou=users"
#define ALD_LDAP_USER_OCLASS        "person,posixAccount,shadowAccount,x-ald-user, inetOrgPerson"
#define ALD_LDAP_USER_CLASS         "objectClass=x-ald-user"
#define ALD_LDAP_USER_NAME          "uid"
#define ALD_LDAP_USER_UID           "uidNumber"
#define ALD_LDAP_USER_GID           "gidNumber"
#define ALD_LDAP_USER_GECOS         "gecos"
#define ALD_LDAP_USER_HOME          "homeDirectory"
#define ALD_LDAP_USER_SHELL         "loginShell"
#define ALD_LDAP_USER_DESC          "description"
#define ALD_LDAP_USER_FULL_NAME     "cn"
#define ALD_LDAP_USER_SURNAME       "sn"
#define ALD_LDAP_USER_POLICY        "x-ald-kppolicy"
#define ALD_LDAP_USER_CAP           "x-ald-user-cap"
#define ALD_LDAP_USER_CAPS          "x-ald-user-caps"
#define ALD_LDAP_USER_HOSTS         "x-ald-allowed-hosts"
#define ALD_LDAP_USER_HGROUPS       "x-ald-allowed-host-groups"
#define ALD_LDAP_USER_HOME_TYPE     "x-ald-user-home-type"
#define ALD_LDAP_USER_HOME_SRV      "x-ald-user-home-server"
#define ALD_LDAP_USER_LGROUPS       "x-ald-user-local-groups"
#define ALD_LDAP_USER_MICLVL        "x-ald-user-mic-level"
#define ALD_LDAP_USER_PHOTO         "jpegPhoto"
///@}

/*! \name константы метаданых LDAP (группы) */
///@{
#define ALD_LDAP_GROUP_BASE         "ou=users"
#define ALD_LDAP_GROUP_OCLASS       "posixGroup"
#define ALD_LDAP_GROUP_CLASS        "objectClass=posixGroup"
#define ALD_LDAP_GROUP_NAME         "cn"
#define ALD_LDAP_GROUP_GID          "gidNumber"
#define ALD_LDAP_GROUP_DESC         "description"
#define ALD_LDAP_GROUP_MEMBER       "memberUid"
///@}

/*! \name константы метаданых LDAP (задания) */
///@{
#define ALD_LDAP_TASK_BASE          "ou=tasks,ou=ald-config"
#define ALD_LDAP_TASK_OCLASS        "x-ald-task-object"
#define ALD_LDAP_TASK_CLASS         "objectClass=x-ald-task-object"
#define ALD_LDAP_TASK_ID            "x-ald-id"
#define ALD_LDAP_TASK_NAME          ALD_LDAP_TASK_ID
#define ALD_LDAP_TASK_TYPE          "x-ald-task"
#define ALD_LDAP_TASK_STATUS        "x-ald-status"
#define ALD_LDAP_TASK_TIMESTAMP     "x-ald-timestamp"
#define ALD_LDAP_TASK_DATA          "x-ald-task-data"
#define ALD_LDAP_TASK_ERROR         "x-ald-err-desc"

#define ALD_LDAP_EVTASK_BASE        "ou=event-tasks,ou=ald-config"
///@}

/*! \name константы метаданых LDAP (политика) */
///@{
#define ALD_LDAP_POLICY_BASE        "ou=policies,ou=ald-config"
#define ALD_LDAP_POLICY_OCLASS      "x-ald-krb5-pass-policy"
#define ALD_LDAP_POLICY_CLASS       "objectClass=x-ald-krb5-pass-policy"
#define ALD_LDAP_POLICY_NAME        "cn"
#define ALD_LDAP_POLICY_MAXLIFE     "x-ald-kpp-maxlife"
#define ALD_LDAP_POLICY_MINLIFE     "x-ald-kpp-minlife"
#define ALD_LDAP_POLICY_MINLEN      "x-ald-kpp-minlen"
#define ALD_LDAP_POLICY_MINCLASSES  "x-ald-kpp-minclasses"
#define ALD_LDAP_POLICY_HISTORY     "x-ald-kpp-history"
///@}

/*! \name константы метаданых LDAP (группы сервисов) */
///@{
#define ALD_LDAP_SGROUP_BASE        "ou=ald-config"
#define ALD_LDAP_SGROUP_OCLASS      "groupOfNames"
#define ALD_LDAP_SGROUP_CLASS       "objectClass=groupOfNames"
#define ALD_LDAP_SGROUP_NAME        "cn"
#define ALD_LDAP_SGROUP_DESC        "description"
#define ALD_LDAP_SGROUP_MEMBER      "member"
///@}

/*! \name константы метаданых LDAP (группы компьютеров) */
///@{
#define ALD_LDAP_HGROUP_BASE        "ou=hosts"
#define ALD_LDAP_HGROUP_OCLASS      "x-ald-host-group-object"
#define ALD_LDAP_HGROUP_CLASS       "objectClass=x-ald-host-group-object"
#define ALD_LDAP_HGROUP_NAME        "cn"
#define ALD_LDAP_HGROUP_DESC        "description"
#define ALD_LDAP_HGROUP_HOSTS       "x-ald-hosts"
///@}

/*! \name константы метаданых LDAP (компьютеры) */
///@{
#define ALD_LDAP_HOST_BASE          "ou=hosts"
#define ALD_LDAP_HOST_OCLASS        "x-ald-host-object"
#define ALD_LDAP_HOST_CLASS         "objectClass=x-ald-host-object"
#define ALD_LDAP_HOST_NAME          "cn"
#define ALD_LDAP_HOST_DESC          "description"
#define ALD_LDAP_HOST_FLAGS         "x-ald-host-flags"
#define ALD_LDAP_SERVER_ID          "x-ald-id"
///@}

/*! \name константы метаданых LDAP (ald-config) */
///@{
#define ALD_LDAP_CONFIG_CLASS       "objectClass=organizationalUnit"
#define ALD_LDAP_CONFIG_FNAME       "ou=ald-config"
#define ALD_LDAP_CONFIG_BASE        "ou=ald-config"
#define ALD_LDAP_TMSTMP_OCLASS      "x-ald-timestamp-object"
#define ALD_LDAP_TMSTMP_CLASS       "objectClass=x-ald-timestamp-object"
#define ALD_LDAP_TMSTMP_NAME        "cn"
#define ALD_LDAP_TMSTMP_VALUE       "x-ald-timestamp"
#define ALD_LDAP_SRV_TMSTMP_NAME    "server-timestamp"
#define ALD_LDAP_CLNT_TMSTMP_NAME   "client-timestamp"
#define ALD_LDAP_NO_TIMESTAMP       "NO_TIMESTAMP"
///@}

/*! \name константы метаданых LDAP (настройки задач) */
///@{
#define ALD_LDAP_TASKSET_BASE       "ou=tasks,ou=ald-config"
#define ALD_LDAP_TASKSET_CLASS      "objectClass=x-ald-task-settings-object"
#define ALD_LDAP_TASKSET_FNAME      "cn=task-settings"
#define ALD_LDAP_TASKSET_HISTORY    "x-ald-task-history"
///@}

/*! \name константы метаданых LDAP (группы администраторов) */
///@{
#define ALD_AGROUP_ADMINISTRATORS   "administrators"
#define ALD_AGROUP_HOSTADDERS       "hostadders"
#define ALD_LDAP_AGROUP_BASE        "ou=ald-config"
#define ALD_LDAP_AGROUP_OCLASS      "groupOfNames"
#define ALD_LDAP_AGROUP_CLASS       "objectClass=groupOfNames"
#define ALD_LDAP_AGROUP_NAME        "cn"
#define ALD_LDAP_AGROUP_DESC        "description"
#define ALD_LDAP_AGROUP_MEMBER      "member"
///@}

/*! \name константы метаданых LDAP (доверенные домены) */
///@{
#define ALD_LDAP_TD_BASE        "ou=trustedDomains"
#define ALD_LDAP_TD_OCLASS      "x-ald-trusted-domain-object"
#define ALD_LDAP_TD_CLASS       "objectClass=x-ald-trusted-domain-object"
#define ALD_LDAP_TD_NAME        "cn"
#define ALD_LDAP_TD_KDC         "host"
#define ALD_LDAP_TD_DESC        "description"
#define ALD_LDAP_TD_DIR         "x-ald-trust-direction"
///@}

/*! \name константы метаданых LDAP (шаблоны протоколирования) */
///@{
#define ALD_LDAP_LOG_CONFIG         "aldlog"
#define ALD_LDAP_LOG_CONFIG_CLASS   "objectClass=olcALDLogConfig"
#define ALD_LDAP_LOG_CONFIG_FNAME   "olcOverlay=aldlog"
#define ALD_LDAP_LOG_CONFIG_BASE    "olcDatabase={1}hdb,cn=config"
#define ALD_LDAP_LOG_CONFIG_NAME    "olcOverlay"
#define ALD_LDAP_LOG_CONFIG_DEST    "olcALDLogFile"
#define ALD_LDAP_LOG_CONFIG_TPL     "olcALDLogTpl"
///@}

/*! \name константы метаданых LDAP документы) */
///@{
#define ALD_LDAP_DOC_BASE           "ou=documents,ou=ald-config"
#define ALD_LDAP_DOC_OCLASS         "document"
#define ALD_LDAP_DOC_CLASS          "objectClass=document"
#define ALD_LDAP_DOC_NAME           "documentIdentifier"
#define ALD_LDAP_DOC_TITLE          "documentTitle"
#define ALD_LDAP_DOC_VERSION        "documentVersion"
#define ALD_LDAP_DOC_LOCATION       "documentLocation"
#define ALD_LDAP_DOC_DESC           "description"

#define ALD_LDAP_DOC_INTERNAL       "ALD://LDAP"
///@}

/*! \name константы метаданых LDAP (информация о домене) */
///@{
#define ALD_LDAP_DOM_ORG            "o"
#define ALD_LDAP_DOM_STATE          "st"
#define ALD_LDAP_DOM_TEL            "telephoneNumber"
#define ALD_LDAP_DOM_ADDR           "postalAddress"
#define ALD_LDAP_DOM_DESC           "description"
///@}

/*! \name константы метаданых LDAP (операционные атрибуты) */
///@{
#define ALD_LDAP_CREATE_TIMESTAMP   "createTimestamp"
#define ALD_LDAP_MODIFY_TIMESTAMP   "modifyTimestamp"
#define ALD_LDAP_CREATORS_NAME      "creatorsName"
#define ALD_LDAP_MODIFIERS_NAME     "modifiersName"

#define ALD_LDAP_ALL_OBJECTS         "(objectClass=*)"
#define ALD_LDAP_CLASS_FILTER(class) (string("(")+class+")").c_str()

#define ALD_ALDD_TIMESTAMP_NAME     "aldd-timestamp"

///@}

///@}

#endif // ALD_LDAP_DEFINITIONS
