/*! \file msg-definitions.h
 * \brief Объявление общих шаблонов сообщений пользователю
 * \ingroup ALDMessages_group
 */

#ifndef ALD_MSG_DEFINITIONS
#define ALD_MSG_DEFINITIONS

#include "ALDUtils.h"

namespace ALD
{
/*! \defgroup ALDMessages_group Общие шаблоны сообщений пользователю (msg-definitions.h)
 * \brief Объявление общих шаблонов сообщений пользователю
 * @{
 */

/*! \name Работа с именами объектов */
///@{
// universal common messages
#define OBJ_USER      _C("user")
#define OBJ_GROUP     _C("group")
#define OBJ_POLICY    _C("policy")
#define OBJ_DOMAIN    _C("domain")
#define OBJ_TASK      _C("task")
#define OBJ_EVTASK    _C("event")
#define OBJ_SERVICE   _C("service")
#define OBJ_SGROUP    _C("service group")
#define OBJ_HGROUP    _C("host group")
#define OBJ_HOST      _C("host")
#define OBJ_OBJECT    _C("object")
#define OBJ_ADMGROUP  _C("group of administrators")
#define OBJ_DOMAIN_LOG_CFG _C("domain log configuration")
#define OBJ_TD        _C("trusted domain")
#define OBJ_DNS       _C("DNS name")
#define OBJ_DOCUMENT  _C("document")

#define OBJ_WITH_ID _C("with ID")

#define OBJNAME(obj, name) string((!name.empty() && isdigit(name[0])) ? string(OBJ_WITH_ID)+" "+name : "'"+name+"'")
///@}

/*! \name Сообщения пользователю */
///@{
#define DESC_CANCELED _C("Action cancelled.")

#define ERR_BAD_NAME(obj, name, desc)     FMTSTR(3, _C("Incorrect name of object %s '%s'.%s"), obj, name.c_str(), desc)

#define WARN_NOT_FOUND(obj, name)         FMTSTR(2, _C("Object %s %s not found."), obj, \
                                                  OBJNAME(obj, name).c_str())
#define WARN_EXISTS(obj, name)            FMTSTR(2, _C("Object %s %s already exists."), obj, \
                                                  OBJNAME(obj, name).c_str())
#define WARN_REMOVE(obj, name, desc)      FMTSTR(3, _C("You are going to remove object %s %s.%s"), obj, \
                                                  OBJNAME(obj, name).c_str(), desc)
#define ERR_ADDITION(obj, name)           FMTSTR(3, _C("Failed to create object %s %s. %s"), obj, \
                                                  OBJNAME(obj, name).c_str(), DESC_CANCELED)
#define ERR_DELETION(obj, name)           FMTSTR(3, _C("Failed to remove object %s %s. %s"), obj, \
                                                  OBJNAME(obj, name).c_str(), DESC_CANCELED)
#define ERR_MODIFICATION(obj, name)       FMTSTR(3, _C("Failed to modify object %s %s. %s"), obj, \
                                                  OBJNAME(obj, name).c_str(), DESC_CANCELED)

#define WARN_DELETION(obj, name)          FMTSTR(2, _C("Not all conditions are satisfied for the removal " \
                                                    "of object %s %s. Action cancelled."), obj,  OBJNAME(obj, name).c_str())

#define MSG_CREATE_OBJECT(obj, name)      FMTSTR(2, _C("Creating object %s %s"), obj, \
                                                  OBJNAME(obj, name).c_str())

#define MSG_UPDATE_OBJECT(obj, name)      FMTSTR(2, _C("Modifying object %s %s"), obj, \
                                                  OBJNAME(obj, name).c_str())

#define MSG_REMOVE_OBJECT(obj, name)      FMTSTR(2, _C("Removing object %s %s"), obj, \
                                                  OBJNAME(obj, name).c_str())

#define MSG_OBJECT_LOADING(obj, name)      FMTSTR(2, _C("Loading object %s '%s..."), obj, \
                                                  name.c_str())

#define MSG_OBJECT_LOADED(obj, name)      FMTSTR(2, _C("Object %s '%s' is loaded."), obj, \
                                                  name.c_str())

#define ERR_OBJECT_LOADING(obj, name, msg)      FMTSTR(3, _C("Failed to load object '%s:%s': %s."), \
                                                  obj.c_str(), name.c_str(), msg)

#define ERR_INVALID_PROP_ID(obj, id)  FMTSTR(2, _C("Unknown object %s property ID (%d)"), obj, id)

#define DESC_EMPTY ""
#define FMT_USER_NAME _C("\nThere ara some restrictions on user name. See VALID_USER_NAMES "\
                        "parameter in 'ald.conf' file. By default it should contain "\
                        "lower case latin letters, numbers, '-', '_', '.' and be less " \
                        "than 32 characters. Should start with a letter.")
#define FMT_GROUP_NAME _C("\nThere ara some restrictions on group name. See VALID_GROUP_NAMES "\
                          "parameter in 'ald.conf' file. By default it should contain "\
                          "latin letters, numbers, '-', '_', '.', ' ' and be less " \
                          "than 32 characters. Should start with a letter.")
#define FMT_SGROUP_NAME FMT_GROUP_NAME
#define FMT_HGROUP_NAME FMT_GROUP_NAME
#define FMT_POLICY_NAME _C("\nShould contain latin letters, digits, minus and underscore chars.")
#define FMT_SERVICE_NAME _C("\nShould have form 'service/host'. Where 'service' should contain " \
                           "lower case latin letters, numbers, '-', '_' and be less " \
                           "than 32 characters. Should start with a letter.")
#define FMT_HOST_NAME _C("\nMay contain latin letters, digits, '-', '.'. " \
                           "Should be short or fully qualified domain name. " \
                           "Should not start with a period(.).")
#define FMT_DOMAIN_NAME _C("\nMay contain latin letters, digits, '-', '.'. " \
                           "Must have prefix of a period(.).")

#define FMT_DNS_NAME _C("\nMay contain maximum 255 octets with maximum 63 octets between separators.")

// messages for principals

#define WARN_PRINCIPAL_NOT_FOUND(obj, name)  FMTSTR(3, _C("Kerberos principal for %s '%s' not found. %s"), \
                                          obj, name.c_str(), WARN_POSSIBLE_INTEGRITY_ERROR)

#define WARN_PRINCIPAL_WITHOUT_OBJ(obj, name)  FMTSTR(3, _C("Kerberos principal for %s '%s' exists. %s"), \
                                          obj, name.c_str(), WARN_POSSIBLE_INTEGRITY_ERROR)

#define WARN_PRINCIPAL_EXISTS(user)  FMTSTR(1, _C("Kerberos principal '%s' already exists."), \
                                          user.c_str())

// messages for user manipulation

#define ERR_MULTIPLE_USERS(user)  FMTSTR(1, _C("Multiple users with the same name or uid '%s'."), user.c_str())

#define MSG_SCHEDULED_UPDATE_DELAYED  _C("\nNOTE. Some parameters (like user priveledges or home directory) " \
                                      "will be updated in a minute by 'aldd' daemon.\n")

#define ASK_REMOVE_PRIMARY_GROUP(group) FMTSTR(1, _C("The primary group '%s' of the deleted user is empty.\n" \
                                          "Remove it?"), group.c_str())

#define ASK_DEFAULT_PASSWORD  _C("Enter default password for a user")
#define ASK_USER_PASSWORD(user) FMTSTR(1, _C("Enter new password for user '%s'"), user.c_str())

#define ERR_INVALID_UID(uid, muid) FMTSTR(2, _C("Invalid user identification number %d. Must be more than mimimum uid %d."), \
                                    uid, muid)

#define WARN_USERPOLICY_NOTEQUAL(user, pol1, pol2)  FMTSTR(3, _C("Policy for user '%s' doesn't match in LDAP ('%s') vs Kerberos ('%s')."), \
                                          user.c_str(), pol1.c_str(), pol2.c_str())
// messages for group manipulation

#define ERR_MULTIPLE_GROUPS(group)  FMTSTR(1, _C("Multiple groups with the same name or gid '%s'."), group.c_str())

#define ERR_PRIMARY_MEMBERS_EXIST(group, members) FMTSTR(2, _C("Group '%s' is referred by primary members:\n" \
                      "%s\n" \
                      "Modify these users, so they don't refer to this group."), group.c_str(), members.c_str())

#define WARN_GROUP_RM _C("\nAll members of this group will lose their membership, but will remain " \
                      "in the database. Delete them manually if needed.")

#define WARN_MEMBERS_ALREADY_EXIST(grp, mems) FMTSTR(2, _C("The following user(s) is(are) already member(s) of group '%s':\n" \
                                            "%s"), grp.c_str(), mems.c_str())

#define WARN_ALREADY_PRIMARY_MEMBERS(grp, mems) FMTSTR(2, _C("The following user(s) is(are) already primary member(s) of " \
                                                         "group '%s':\n" \
                                                         "%s"), grp.c_str(), mems.c_str())

#define WARN_GROUP_REMOVE_MEMBERS_NOT_EXIST(grp, mems) FMTSTR(2, _C("The following user(s) is(are) not secondary member(s) of " \
                                                         "group '%s':\n" \
                                                         "%s"), grp.c_str(), mems.c_str())

#define ERR_INVALID_GID(gid, mgid) FMTSTR(2, _C("Invalid group identification number %d. Must be more than mimimum gid %d."), \
                                    gid, mgid)
// messages for policy manipulation

#define ERR_MULTIPLE_POLICIES(policy)  FMTSTR(1, _C("Multiple policies with the same name '%s'."), policy.c_str())

#define ERR_POLICY_USED(policy, users) FMTSTR(2, _C("Unable to remove policy '%s', because it is used by the users:\n" \
                                         "%s\n" \
                                         "Modify these users not to use this policy."), policy.c_str(), users.c_str())

#define ERR_INVALID_LIFETIME(name) FMTSTR(1, _C("Incorrect lifetime parameter '%s'. " \
                                          "Should be in form: NNd (for days) or NNh (for hours) or NNm (for minutes)."), \
                                          name)

#define WARN_KRBPOLICY_NOT_FOUND(name)  FMTSTR(2, _C("Kerberos policy '%s' not found. %s"), \
                                          name.c_str(), WARN_POSSIBLE_INTEGRITY_ERROR)

#define WARN_POLICY_EXISTS(policy)  FMTSTR(1, _C("Kerberos policy '%s' already exists."), \
                                          policy.c_str())

#define WARN_KRBPOLICY_WITHOUT_OBJ(name)  FMTSTR(2, _C("Kerberos policy '%s' exists. %s"), \
                                          name.c_str(), WARN_POSSIBLE_INTEGRITY_ERROR)

#define WARN_ALDKRBPOLICY_NOTEQUAL(name, info)  FMTSTR(2, _C("Policy '%s' doesn't match in LDAP vs Kerberos.%s"), \
                                          name.c_str(), (string(" ")+info).c_str())

// messages for service manipulation

#define ERR_SYSTEM_SERVICE(service) FMTSTR(1, _C("Service '%s' is a system or host service."), service.c_str())

#define WARN_SYSTEM_SERVICE_RM(service) FMTSTR(1, _C("%s\nRemoving system services will lead to incorrect work of ALD.\n" \
                                        "To remove 'host/', 'cifs/' and 'nfs/' services use 'host-rm' command.\n"), \
                                        ERR_SYSTEM_SERVICE(service))

// messages for service group manipulation

#define ERR_MULTIPLE_SGROUPS(sgroup)  FMTSTR(1, _C("Multiple service groups with the same name '%s'."), sgroup.c_str())

#define WARN_SGROUP_RM _C("\nAll members of this service group will lose their membership, but will remain " \
                      "in the database. Delete them manually if needed.")

// messages for administrators group manipulation

#define ERR_MULTIPLE_AGROUPS  FMTSTR(1, _C("Multiple groups of administrators. %s"), \
                                        WARN_POSSIBLE_INTEGRITY_ERROR)

// messages for domain log configuration manipulation

#define ERR_MULTIPLE_LOG_CFGS  FMTSTR(1, _C("Multiple domain log configurations. %s"), \
                                        WARN_POSSIBLE_INTEGRITY_ERROR)

#define MSG_LOG_TPL_ALTER(tpl) FMTSTR(1, _C("alter log template '%s'"), tpl.c_str())
#define MSG_LOG_DEST_ALTER(dest) FMTSTR(1, _C("alter log destination '%s'"), dest.c_str())

// messages for host group manipulation

#define ERR_MULTIPLE_HGROUPS(hgroup)  FMTSTR(1, _C("Multiple host groups with the same name '%s'."), hgroup.c_str())

#define WARN_HGROUP_RM _C("\nAll members of this host group will lose their membership, but will remain " \
                      "in the database. Delete them manually if needed.")

// messages for host manipulation

#define ERR_MULTIPLE_HOSTS(host)  FMTSTR(1, _C("Multiple hosts with the same name '%s'."), host.c_str())

// messages for document manipulation

#define ERR_MULTIPLE_DOCS(doc)  FMTSTR(1, _C("Multiple documents with the same name '%s'."), doc.c_str())

// messages for domain manipulation

#define ERR_MULTIPLE_DOMAINS(domain)  FMTSTR(1, _C("Multiple domains with the same name '%s'."), domain.c_str())

#define WARN_NO_LDAP_CONNECT _C("No connect to LDAP server or ALD database not initialized.")

#define ERR_DB_NOT_INITIALIZED  _C("Astra Linux Directory database is not initialized.\n" \
                                  "Run 'ald-init init' command or restore from backup.")

#define ERR_DB_HAS_DIFFERENT_DOMAIN(dom1, dom2) FMTSTR(2, _C("Astra Linux Directory database domain '%s' " \
                                      "mismatches domain in 'ald.conf' file '%s'.\n" \
                                      "Create new database with 'ald-init init' command " \
                                      "or use 'backup-ldif' and 'restore-backup-ldif' commands to change domain."), \
                                      dom1.c_str(), dom2.c_str())

#define ERR_DB_INVALID_REALM(krb5realm, domain) FMTSTR(2, _C("Astra Linux Directory misconfigured. Kerberos realm '%s' " \
                      "doesn't correspond domain in 'ald.conf' file '%s'.\n" \
                      "Create new database with 'ald-init init' command " \
                      "or use 'backup-ldif' and 'restore-backup-ldif' commands to change domain."), \
                      krb5realm.c_str(), domain.c_str())

#define ERR_INVALID_TASK_HISTORY(val) FMTSTR(1, _C("Invalid task history parameter '%s'.\n" \
                                               "Task history parameter should be > 2 and < 2000."), val.c_str())

#define ERR_INVALID_DOMAIN_PARAMETER(prm, val) FMTSTR(2, _C("Domain parameter '%s' has invalid value '%s'."), prm, \
                                                  val.c_str())

#define ERR_INVALID_VERSION(clntver, srvver) FMTSTR(2, _C("Client version '%s' doesn't match server version '%s'."), \
                                                    clntver.c_str(), srvver.c_str())

// messages for task

#define ERR_MULTIPLE_TASKS(TaskID)  FMTSTR(1, _C("Multiple tasks with the same ID '%s'."), TaskID.c_str())

#define ERR_INVALID_TASK_ID(TaskID) FMTSTR(1, _C("Invalid task id '%s'."), TaskID.c_str())

// messages for host

#define ERR_BAD_HOST_NAME(name, desc)     FMTSTR(2, _C("Incorrect host name '%s'.%s"), name.c_str(), desc)

#define ERR_BAD_HOST_LOCALHOST _C("Host name 'localhost' is prohibited.")

#define ERR_BAD_HOST_DOMAIN(host, domain) FMTSTR(2, _C("Incorrect domain in host name '%s'.\n" \
                                  "A host name should be a short name or fully qualified name ending with " \
                                  "'%s' domain"), host.c_str(), domain.c_str())
// messages for daemons

#define MSG_SERVICE_MANAGE(svc, op) FMTSTR(2, _C("Manage service %s %s..."), svc.c_str(), op.c_str())

#define MSG_SERVICE_STOP(svc) FMTSTR(1, _C("Stopping service %s..."), svc.c_str())

#define MSG_SERVICE_START(svc) FMTSTR(1, _C("Starting service %s..."), svc.c_str())

#define MSG_SERVICE_RESTART(svc) FMTSTR(1, _C("Restarting service %s..."), svc.c_str())

#define MSG_SERVICE_RELOAD(svc) FMTSTR(1, _C("Reload service %s..."), svc.c_str())

#define MSG_SERVICE_ENABLE(svc) FMTSTR(1, _C("Enabling service %s..."), svc.c_str())

#define MSG_SERVICE_DISABLE(svc) FMTSTR(1, _C("Disabling service %s..."), svc.c_str())

/*
#define WARN_SERVICE_MANAGE(svc)  FMTSTR(2, _C("Script '/etc/init.d/%s' returned code %d."), \
                                          svc.c_str())
*/

#define ERR_UNKNOWN_SERVICE_OPERATION _C("Unknown service management operation.")

#define ERR_SERVICE_OPERATION(svc, op, err) FMTSTR(3, _C("Failed to %s service %s. " \
                                                    "Exit status %d."), op, svc.c_str(), err)

#define ERR_SERVICE_INSTALL_OPERATION(svc, op, err) FMTSTR(3, _C("Failed to %s service %s. " \
                                                    "Exit status %d."), op, svc.c_str(), err)

// common messages

#define PROCEED _C("Proceed?")
#define WARN_PROCEED _C("Are you SURE to PROCEED?")

#define ALL_CORRECT _C("All correct?")

#define ERR_PATH_SYNTAX(path) FMTSTR(1, _C("Incorrect path '%s'.\n" \
                              "Should be an absolute path. Should not contain any exotic characters.\n" \
                              "Characters allowed: latin letters, digits, '-', '_'.\n" \
                              "Constructs like '..' and '//' are not allowed."), path.c_str())

#define ERR_BAD_GECOS(gecos)  FMTSTR(1, _C("Incorrect GECOS parameter '%s'.\n" \
                        "Format: user_full_name,[room_number],[phone],[home_phone][,other]\n" \
                        "Not allowed character : and !# at the end."), gecos.c_str())

#define ERR_BAD_HOME_FS(homefs, fss)  FMTSTR(2, _C("Incorrect home FS type '%s'.\n" \
                                            "Supported FS: %s"), homefs.c_str(), fss.c_str())

#define PROMPT_GECOS    _C("Enter GECOS field (user_full_name,[room_number],[phone],[home_phone][,other])\n" \
                           "Allowed: letters, digits, space, -.+()_ characters.\n" \
                           "GECOS")

#define ERR_MUTUAL_OPTIONS(opt1, opt2)  FMTSTR(2, _C("Options '--%s' and '--%s' are mutual exclusive."), opt1, opt2)

#define ERR_NEITHER_OPTIONS(opt1, opt2) FMTSTR(2, _C("Neither '--%s' nor '--%s' option is specified."), opt1, opt2)

#define ERR_OPTION_NEEDED(opt) FMTSTR(1, _C("Option '--%s' is needed."), opt)

#define WARN_NOTHING_TO_DO(cmd) FMTSTR(1, _C("Nothing to do for '%s' command."), cmd.c_str())

#define ERR_ARG_OPT_CONFLICT(cmd) FMTSTR(1, _C("Argument conflicts with an option in '%s' command."), cmd.c_str())

#define ERR_INVALID_OPTION_ARGUMENT(opt) FMTSTR(1, _C("Invalid argument format for option '%s'."), opt.c_str())

#define WARN_POSSIBLE_INTEGRITY_ERROR _C("\nPossible integrity error.\n" \
                                        "Invoke 'test-integrity' command " \
                                        "and/or try to reinvoke the current command after fixing problems.")

#define ERR_IN_PASSFILE(file, line)  FMTSTR(2, _C("%s:%d: Parse error in password file.\n" \
                                              "All lines should have format 'user:password'.\n" \
                                              "'user' may have format of Kerberos principal (w/o realm), " \
                                              "(e.g. 'admin/admin', 'K/M') or Unix user (lower case latin " \
                                              "letters, numbers, '-', '_', should be less 32 chars). " \
                                              "Should start with a letter."), file.c_str(), line)

#define ERR_PASSFILE_PERM(file, perm)  FMTSTR(2, _C("Password file '%s' has dangerous permissions (%o).\n" \
                                                "This may be a security hole. Password file should have 0600 mode."), \
                                                file.c_str(), perm)

#define ERR_NO_PASSWORD(user) FMTSTR(1, _C("No password for user '%s' was found in password file " \
                                       "or no --pass-file option was specified. In 'force' mode passwords should " \
                                       "be transferred only via a password file."), user.c_str())

#define ERR_DUP_PASSWORD(user) FMTSTR(1, _C("Password for user '%s' meet twice in password file."), user.c_str())

#define ERR_CHANGE_PASSWORD(user) FMTSTR(1, _C("Failed to change password for user '%s'."), user.c_str())

#define WARN_INSUFFICIENT_ACCESS _C("Insufficient access. The user should have administrator privilege.")

#define ERR_INVALID_CONFIG_PARAMETER(prm, val) FMTSTR(2, _C("Configuration parameter '%s' has invalid value '%s'."), prm, \
                                                  val.c_str())

#define ERR_INVALID_ATTRIBUTE_VALUE(obj, name, attr, val) FMTSTR(4, _C("Attribute '%s' of %s '%s' has invalid value '%s'."), \
                                                                    attr, obj, name.c_str(), val.c_str())

#define ERR_EMPTY_ARGUMENT FMTSTR(1, _C("Argument is empty for '%s'."), __FUNCTION__)

#define ERR_INTERNAL_COMMAND(cmd) FMTSTR(1, _C("Command '%s' is for internal use only.\n" \
                                           "Do not call it explicitly."), cmd.c_str())

#define ERR_INVALID_USAGE(app) FMTSTR(1, _C("Invalid usage of %s."), app.c_str())

#define WARN_NOT_ALL_CONDITION(cmd) FMTSTR(1, _C("Not all conditions are satisfied for %s"), cmd.c_str())

#define INFO_EXEC_COMMAND(cmd) FMTSTR(1, _C("Executing '%s' command..."), cmd)

#define ERR_UNKNOWN_COMMAND(cmd) FMTSTR(1, _C("Unknown command '%s'."), cmd)

#define ERR_UNKNOWN_OPTION(opt) FMTSTR(1, _C("Unknown option '%s'."), opt)

#define WARN_NOTHING_TO_UNINSTALL _C("Directory '/etc/ald' is not found.\n" \
                                    "Astra Linux Directory is already uninstalled.")

#define ERR_FAILED_TO_OPEN_DIR(dir)  FMTSTR(1, _C("Failed to open directory '%s'."), dir.c_str())

#define ERR_FAILED_TO_OPEN_FILE(filename) FMTSTR(1, _C("Failed to open file '%s'."), filename.c_str())

#define ERR_FAILED_TO_CREATE_FILE(filename) FMTSTR(1, _C("Failed to create file '%s'."), filename.c_str())

#define ERR_FILE_SAVE(filename) FMTSTR(1, _C("Failed to save file '%s'."), filename.c_str())

#define ERR_NOT_IMPLEMENTED(feature) FMTSTR(1, _C("Feature '%s' is not inplemented."), feature)

#define ERR_ALD_NOT_CONFIGURED(cfg)     FMTSTR(1, _C("Astra Linux Directory is not configured.\n" \
                                             "Fill config file '%s' correctly."), cfg.c_str())

#define ERR_INVALID_HOST_TYPE(type)     FMTSTR(1, _C("Invalid host type %d."), type)

#define ERR_FILE_NOT_EXISTS(filename)   FMTSTR(1, _C("File '%s' doesn't exists."), filename.c_str())

#define ERR_ROLLING_BACK_TRANSACTION _C("ERROR occurred during complex transaction. Rolling back...")

#define ERR_UNEXPECTED FMTSTR(4, _C("Unexpected error %d in %s:%u - %s()"), errno, ExtractFileName(__FILE__), __LINE__, __FUNCTION__)

#define ERR_NAME_RESOLUTION(err) FMTSTR(1, _C("Incorrect setup of name resolution system.\n%s"), err)

#define ERR_STAT(file)  FMTSTR(1, _C("Error stat '%s':%m"), file.c_str())

#define MSG_INTEGRITY_OK  _C("ok")
#define MSG_INTEGRITY_ERR  _C("error")
#define MSG_INTEGRITY_WARN  _C("warning")
#define MSG_INTEGRITY_FIXED  _C("fixed")
#define ERR_INTEGRITY(err)   FMTSTR(1, _C("-- INTEGRITY ERROR:\n%s\n--"), err)

#define ERR_INVALID_OBJECT _C("ALD object isn't valid.")
#define MSG_INSTALL_EXTENSION(ext) FMTSTR(1, _C("Installing ALD exstension: %s..."), ext)

#define ERR_ALD_ABSTRACT_OBJECT _C("Invalid usage of the CALDObject. It is an abstract base class!")

#define MSG_GROUP_MEMBER_ADD(member) FMTSTR(1, _C("adding member '%s'"), member.c_str())
#define MSG_GROUP_MEMBER_RM(member) FMTSTR(1, _C("removing member '%s'"), member.c_str())

#define WARN_NOT_SUPPORTED_CM _C("This operation is not supported in the compatibility mode.")

#define WARN_FILE_EXISTS(path)      FMTSTR(1, _C("File %s already exists."), path.c_str())

#define ERR_MODULE_LOADING _C("Module isn't loaded.")

#define MSG_DISABLED _C("Disabled")

#define MSG_TRUSTED_CHANGES  _C("\nNOTE. Trusted relationships changes require reconfiguration on clients.\n" \
                                "This can be done by 'ald-client restart' command.")

#define WARN_TRUSTED_REMOVING  _C("\nRemoving trusted relationships requires changes on server " \
                           "and can be done in a minute by 'aldd' daemon.\n")

#define WARN_KRB_ACL_CHANGES  _C("Kerberos ACL may be changed. Don't forget invoke 'admin-apply' command.")

#define ERR_RPC_INVALID_ARGUMENTS _C("Invalid arguments for RPC command.")

#define ERR_RPC_PROTOCOL _C("RPC Protocol error.")

#define ERR_FORK(reason) FMTSTR(1, _C("Failed to fork. %s"), reason)

#define ERR_EMPTY_FIELD(field) FMTSTR(1, _C("Field '%s' can't be empty."), field)

#define INFO_DC_DETECTED(domain, server) FMTSTR(2, _C("ALD server for domain '%s' detected on '%s'."), domain.c_str(), server.c_str())
#define WARN_DC_NOTDETECTED(domain) FMTSTR(1, _C("ALD server for domain '%s' not detected."), domain.c_str())

#define WARN_RESTART _C("Also while executing this command - LDAP, Kerberos, NFS/Samba and some other services may be stopped and restarted.")

#define INFO_STAT_OPTION _C(" --stat - displays operational info.")
///@}

///@}

} // ALD

#endif // ALD_MSG_DEFINITIONS
