/*! \file rpc-definitions.h
 * \brief Объявление идентификаторов команд RPC интерфейса Astra Linux Directory
 * (см. \ref ald-rpc.h, \ref ALDRpcUtils.h)
 * \ingroup ALDRPCCommands_group
 */

#ifndef ALD_RPC_DEFINITIONS
#define ALD_RPC_DEFINITIONS

/*! \defgroup ALDRPCCommands_group Идентификаторы команд RPC интерфейса  (rpc-definitions.h)
 * \brief Объявление идентификаторов команд RPC интерфейса Astra Linux Directory
 * \ingroup IALDRpcWrapper_group
 * @{
 */

/*! \name Ограничения RPC */
///@{
#define ALD_RPC_STR_LIMIT   1024*16
#define ALD_RPC_MAX_LIMIT   1024*1024
#define ALD_RPC_BUFF_LIMIT  1024*16
///@}

// RPC Command definitions
/*! \name Идентификаторы RPC команд ALD */
///@{
// System commands
#define ALD_RPC_CMD_HANDSHAKE       "rpc-handshake"
#define ALD_RPC_CMD_AUTH            "rpc-auth"
#define ALD_RPC_CMD_CREDS           "rpc-creds"
#define ALD_RPC_CMD_SASL_START      "rpc-sasl-start"
#define ALD_RPC_CMD_SASL_CONTINUE   "rpc-sasl-continue"
#define ALD_RPC_CMD_STATUS          "rpc-status"
#define ALD_RPC_CMD_LIST            "rpc-list"
#define ALD_RPC_CMD_STATISTICS      "rpc-statistics"
#define ALD_RPC_CMD_EXECUTE         "rpc-execute"
#define ALD_RPC_CMD_LS              "rpc-ls"

// Domain commands
#define ALD_RPC_CMD_REMOVE_OBJ      "rpc-remove-object"
#define ALD_RPC_CMD_ADMGRP_MOD      "rpc-agroup-mod"
#define ALD_RPC_CMD_PRINC_LIST      "rpc-princ-list"
#define ALD_RPC_CMD_PRINC_GET       "rpc-princ-get"
#define ALD_RPC_CMD_TRUSTED_SET     "rpc-trusted-set"
#define ALD_RPC_CMD_DOM_ORG         "rpc-domain-org"

// Service commands
#define ALD_RPC_CMD_SVC_ADD         "rpc-service-add"
#define ALD_RPC_CMD_SVCGRP_MOD      "rpc-sgroup-mod"

// Policy commands
#define ALD_RPC_CMD_POLICY_SET      "rpc-policy-set"
#define ALD_RPC_CMD_POLICY_GET      "rpc-policy-get"
#define ALD_RPC_CMD_POLICY_LIST     "rpc-policy-list"

// Host commands
#define ALD_RPC_CMD_HOST_SET        "rpc-host-set"
#define ALD_RPC_CMD_HOST_GET        "rpc-host-get"
#define ALD_RPC_CMD_HOST_RENEW      "rpc-host-renew"
#define ALD_RPC_CMD_HSTGRP_SET      "rpc-hgroup-set"
#define ALD_RPC_CMD_HSTGRP_MOD      "rpc-hgroup-mod"

// User commands
#define ALD_RPC_CMD_GROUP_SET       "rpc-group-set"
#define ALD_RPC_CMD_GROUP_MOD       "rpc-group-mod"
#define ALD_RPC_CMD_USER_HOSTS      "rpc-user-hosts"
#define ALD_RPC_CMD_USER_SET        "rpc-user-set"
#define ALD_RPC_CMD_USER_ATTR       "rpc-user-attr"

// Logging commands
#define ALD_RPC_CMD_LOG_SET         "rpc-log-set"
#define ALD_RPC_CMD_LOGTPL_CTL      "rpc-logtpl-ctl"

// Task commands
#define ALD_RPC_CMD_TASK_ADD        "rpc-task-add"
#define ALD_RPC_CMD_TASK_MOD        "rpc-task-mod"
#define ALD_RPC_CMD_TASKHIST_SET    "rpc-taskhist-set"

// Document commands
#define ALD_RPC_CMD_DOC_SET         "rpc-doc-set"
#define ALD_RPC_CMD_DOC_GET         "rpc-doc-get"
#define ALD_RPC_CMD_DOC_PUT         "rpc-doc-put"

// LPC Command definitions
#define ALD_LPC_CMD_SPWD            "lpc-user-spwd"
#define ALD_LPC_CMD_GET_COUNTER     "lpc-get-counter"
#define ALD_LPC_CMD_SET_COUNTER     "lpc-set-counter"
#define ALD_LPC_CMD_INC_COUNTER     "lpc-inc-counter"

// Broadcast definitions
#define ALD_BRC_MSG_DOTASKS         "bc-do-tasks"
#define ALD_BRC_MSG_CHECKDC         "bc-check-dc"
#define ALD_BRC_MSG_DCCHANGED       "bc-dc-changed"
#define ALD_BRC_MSG_GETSTATUS       "bc-get-status"
#define ALD_BRC_MSG_RECONFIGURE     "bc-reconfigure"
#define ALD_BRC_MSG_INVALIDATE      "bc-invalidate"
///@}

///@}

#endif // ALD_RPC_DEFINITIONS
